```json
{
  "title": "Embedded videos test",
  "author": "",
  "site": "",
  "published": ""
}
```

A YouTube video:

![](https://www.youtube.com/watch?v=b_PXuEPxN50)

A YouTube nocookie video:

![](https://www.youtube.com/watch?v=b_PXuEPxN50)

A tweet:

![](https://x.com/i/status/1675626836821409792)

An X.com embed:

![](https://x.com/kepano/status/1675626836821409792)

A Vimeo video should stay as iframe:

<iframe src="https://player.vimeo.com/video/45725193?h=a290f71a57" width="100%" height="100%" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen=""></iframe>